==> pant-react-0.1.40.tgz: package/es/data-list/addons/record-actions/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { Icon } from '../../../icon';
import { actionSheet } from '../../../action-sheet';
import { i18n } from '../../../locale';
export function recordActions(options) {
    return {
        onInjectRecord: function (render) { return function (props) {
            return (_jsxs(_Fragment, { children: [render(props), _jsx(RecordActions, __assign({ record: props.record }, options), void 0)] }, void 0));
        }; },
    };
}
function RecordActions(_a) {
    var actions = _a.actions, record = _a.record, actionIcon = _a.actionIcon, cancelText = _a.cancelText;
    var showActions = function () {
        actionSheet({
            round: false,
            actions: actions,
            cancelText: typeof cancelText === 'undefined' ? i18n().cancel : cancelText,
            onSelect: function (_a) {
                var action = _a.action;
                action(record);
            },
        });
    };
    return (_jsx("div", __assign({ className: "pant-data-list__record__actions" }, { children: (actionIcon && React.cloneElement(actionIcon, { onClick: showActions })) || (_jsx(Icon, { name: "ellipsis", onClick: showActions }, void 0)) }), void 0));
}

==> pant-react-0.1.43.tgz: package/es/data-list/addons/record-actions/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { Icon } from '../../../icon';
import { actionSheet } from '../../../action-sheet';
import { i18n } from '../../../locale';
export function recordActions(options) {
    return {
        onInjectRecord: function (render) { return function (props) {
            return (_jsxs(_Fragment, { children: [render(props), _jsx(RecordActions, __assign({ record: props.record, recordIndex: props.recordIndex }, options), void 0)] }, void 0));
        }; },
    };
}
function RecordActions(_a) {
    var actions = _a.actions, record = _a.record, recordIndex = _a.recordIndex, actionIcon = _a.actionIcon, cancelText = _a.cancelText;
    var showActions = function () {
        actionSheet({
            round: false,
            actions: actions,
            cancelText: typeof cancelText === 'undefined' ? i18n().cancel : cancelText,
            onSelect: function (_a) {
                var action = _a.action;
                action(record, recordIndex);
            },
        });
    };
    return (_jsx("div", __assign({ className: "pant-data-list__record__actions" }, { children: (actionIcon && React.cloneElement(actionIcon, { onClick: showActions })) || (_jsx(Icon, { name: "ellipsis", onClick: showActions }, void 0)) }), void 0));
}
